import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveLinear
} from 'd3';

const svg = select('svg'); 

const width = +svg.attr('width');
const height = +svg.attr('height');

const xValue = d => d.Month;
const yValue = d => d.No_Calls;
const circleRadius = 5;

const xAxisLabel = 'Month';
const yAxisLabel = 'Calls';

const title = 'Number of DA 2018 Calls';

const margin = {top: 60, right: 30, bottom: 60, left: 100};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

const render = data => {
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth);
  const yAxisG = g.append('g')
    .call(yAxis)
  	
  yAxisG.select('.domain')
  		.remove();
  
  yAxisG.append('text')
  	.text(yAxisLabel)
  		.attr('transform', 'rotate(-90)')
  		.attr('x', -innerHeight / 2)
  		.attr('y', -60)
  		.attr('class', 'axisLabel')
  		.attr('text-anchor', 'middle');
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight);
  const xAxisG = g.append('g')
    .call(xAxis)
      .attr('transform', `translate(0, ${innerHeight})`);
      
  xAxisG.select('.domain')
      .remove();
  
  xAxisG.append('text')
  	.text(xAxisLabel)
  		.attr('fill', 'black')
  		.attr('x', innerWidth / 2)
  		.attr('y', 50)
  		.attr('class', 'axisLabel');
  
  g.append('text')
  	.text(title)
  		.attr('y', -20)
  		.attr('class', 'title');
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
  	.curve(curveLinear);
       
  g.append('path')
  	.attr('d', lineGenerator(data))
  	.attr('class', 'line-path');
  	
};

csv('DF_2018_Calls.js')
  .then(data => {
    data.forEach(d => {
      d.Month = +d.Month;
      d.No_Calls = +d.No_Calls;
    });
  	render(data);
	});
